<template>
  <el-dialog :visible.sync="dialogVisible" append-to-body custom-class="user-select-dialog" title="人员选择" top="7vh"
             width="1250px" @close="$emit('close-dialog')" @closed="closed" @open="open">
    <div class="table-content">
      <div class="search-box">
        <el-form v-model="queryParams" :inline="true" label-suffix="：">
          <el-form-item label="姓名">
            <el-input v-model="queryParams['m.name_']" :clearable="true" placeholder="请输入姓名" />
          </el-form-item>
          <el-form-item label="部门">
            <el-input v-model="queryParams['o.name_']" :clearable="true" placeholder="请输入部门" />
          </el-form-item>
          <el-form-item>
            <el-button icon="el-icon-search" type="primary" @click="handleSearch">
              搜索
            </el-button>
            <el-button icon="el-icon-refresh" @click="handleReset">
              重置
            </el-button>
          </el-form-item>
        </el-form>
      </div>
      <el-table v-loading="loading" :cell-style="{ 'text-align': 'center' }" :data="orgUserQueryData"
                :header-cell-style="{ 'text-align': 'center' }" :row-class-name="tableRowClassName"
                :style="{ width: '100%' }" border
                max-height="450px"
                row-key="id" size="mini" @row-click="rowClick">
        <el-table-column align="center" label="序号" type="index" width="70">
        </el-table-column>
        <el-table-column align="center" label="姓名" min-width="150" prop="name" show-overflow-tooltip />
        <el-table-column align="center" label="部门" min-width="150" prop="orgName" show-overflow-tooltip />
        <el-table-column align="center" label="性别" min-width="150" prop="sex" show-overflow-tooltip />
      </el-table>
      <el-pagination ref="paginationPanel" :current-page="queryParams.page" :page-size="queryParams.pageSize"
                     :page-sizes="[20, 30, 40, 50]"
                     :total="queryParams.total" align="right"
                     background
                     layout="total, prev, pager, next" @size-change="handleSizeChange"
                     @current-change="handleCurrentChange"></el-pagination>
    </div>
    <i class="el-icon-right"></i>
    <div class="result-content">
      <div class="title">人员信息</div>
      <div class="info-box">
        <div class="row">
          <div class="item">
            <div class="label">姓名：</div>
            <div class="value">{{ rowInfo.name || '-' }}</div>
          </div>
        </div>
        <div class="row">
          <div class="item">
            <div class="label">部门：</div>
            <div class="value">{{ rowInfo.orgName || '-' }}</div>
          </div>
        </div>
        <div class="row">
          <div class="item">
            <div class="label">性别：</div>
            <div class="value">{{ rowInfo.sex || '-' }}</div>
          </div>
        </div>
      </div>
    </div>
    <template v-slot:footer>
      <el-button type="primary" @click="handleSaveData">
        保 存
      </el-button>
      <el-button @click="dialogVisible = false">取 消</el-button>
    </template>
  </el-dialog>
</template>

<script>
import TeamMemberManage from '@/api/manager/duty/teamMemberManage.js'

export default {
  name: 'UserSelectDialog',
  props: {
    userSelectDialog: {
      default: false,
      type: Boolean
    },
    userName: {
      default: '',
      type: String
    },
    type: {
      default: 'add',
      type: String
    }
  },
  data() {
    return {
      queryParams: {
        page: 1,
        pageSize: 20,
        total: 0,
        'm.name_': '',
        'o.name_': ''
      },
      sorter: [],
      orgUserQueryData: [],  // 用户列表
      loading: false,
      rowInfo: {
        name: ''
      }
    }
  },
  computed: {
    dialogVisible: {
      get() {
        return this.userSelectDialog
      },
      set(val) {
        this.$emit('update:userSelectDialog', val)
      }
    },
    // 加工为后端需要的请求格式
    computedQuery() {
      const querys = [
        {property: 'm.name_', group: 'quick', operation: 'LIKE'},
        {property: 'o.name_', group: 'quick', operation: 'LIKE'}
      ]
      const {pageSize, page, ...item} = this.queryParams
      return {
        pageBean: {pageSize, page},
        querys: querys.flatMap(i => {
          const value = item[i.property]
          if (Array.isArray(value) && !value.length) return []
          if (value === '') return []
          return {group: 'main', relation: 'AND', ...i, value}
        }),
        sorter: this.sorter.filter(i => i.direction !== '')
      }
    }
  },
  created() {
    this.getOrgUserQuery()
  },
  methods: {
    // 弹层打开
    open() {
      this.getOrgUserQuery(rows => {
        this.rowInfo = rows.find(i => i.name === this.userName) || {}
      })
    },

    async getOrgUserQuery(callback = _ => _) {
      this.orgUserQueryData = []
      this.loading = true
      TeamMemberManage.pageQuery(this.computedQuery).then(res => {
        const {rows, total} = res.data
        this.orgUserQueryData = rows
        this.queryParams.total = total
        callback && callback(rows)
        this.loading = false
      })
      const {rows, total} = await TeamMemberManage.pageQuery(this.computedQuery)

    },

    // 弹层关闭
    closed() {
      Object.assign(this.$data, this.$options.data())
    },

    // 保存
    handleSaveData() {

      if (!this.rowInfo.name) return this.$message.warning('请选择人员')
      const {name, orgName, sex, orgId, id} = this.rowInfo
      if (this.type === 'add') {
        this.$emit('userChange', {
          name: name,
          orgName: orgName,
          orgId: orgId,
          userId: id,
          sex: sex
        })
        this.dialogVisible = false
      } else {
        this.$confirm(`确认修改派遣人员为人${name}吗？`, '提示', {
          confirmButtonText: '确认',
          cancelButtonText: '取消',
          type: 'warning'
        }).then(() => {
          this.$emit('userChange', {
            name: name,
            orgName: orgName,
            orgId: id,
            sex: sex
          })
          this.dialogVisible = false
        })
      }
    },


    // 顶部搜索
    handleSearch() {
      this.queryParams.page = 1
      this.getOrgUserQuery()
    },

    // 重置
    handleReset() {
      this.queryParams = this.$options.data().queryParams
      this.getOrgUserQuery()
    },

    //分页页数
    handleCurrentChange(page) {
      this.queryParams.page = page
      this.getOrgUserQuery()
    },

    //分页大小
    handleSizeChange(pageSize) {
      this.queryParams.pageSize = pageSize
      this.getOrgUserQuery()
    },

    // 表格行点击
    rowClick(row) {
      this.rowInfo = row
    },

    //  行样式渲染
    tableRowClassName({row}) {
      const {name} = this.rowInfo
      if (
        row.name === name) {
        return 'row-active'
      }
    }

  }
}
</script>
<style lang="scss" scoped>
::v-deep .user-select-dialog {


  .el-dialog__body {
    display: flex;
    align-items: center;
    row-gap: 20px;
    column-gap: 30px;

    .table-content {
      display: flex;
      flex-direction: column;
      row-gap: 10px;
      height: 550px;
      position: relative;
      box-shadow: 0 0 8px 0 rgba(0, 0, 0, 0.1);
      padding: 20px;
      flex: 7.5;

      .row-active {
        transition: all 0.2s;
        background: #6fa1ff;


        .cell {
          color: #fff;
        }

        &:hover {
          .el-table__cell {
            background: #6fa1ff;
          }
        }
      }
    }

    > i {
      font-size: 30px;
    }

    .result-content {
      box-shadow: 0 0 8px 0 rgba(0, 0, 0, 0.1);
      padding: 20px;
      flex: 2.5;
      display: flex;
      flex-direction: column;
      row-gap: 30px;
      height: 550px;

      .title {
        font-size: 16PX;
        font-weight: 600;
        color: #333;
      }

      .info-box {
        display: flex;
        flex-direction: column;
        row-gap: 10px;

        .row {
          display: flex;

          .item {
            display: flex;
            flex: 1;

            .label {
              flex: 2.5;
              font-size: 14PX;
              color: #555;
            }

            .value {
              flex: 7.5;
              font-size: 14PX;
              color: #606266;
            }
          }
        }
      }
    }
  }
}
</style>
